@@ -4,7 +4,7 @@ use warnings;
 use base qw/Exporter/;
 use 5.008001;
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 use Carp ();
 use Furl::ConnectionCache;
@@ -856,7 +856,12 @@ sub _r500 {
     my($self, $message) = @_;
     $message = Carp::shortmess($message); # add lineno and filename
     return(0, 500, "Internal Response: $message",
-        ['Content-Length' => length($message)], $message);
+        [
+            'Content-Length' => length($message),
+            'Client-Warning' => 'Internal Response',
+            # XXX ^^ EXPERIMENTAL header. Do not depend to this.
+        ], $message
+    );
 }
 
 sub _strerror_or_timeout {
